@@ -1,4 +1,4 @@
-from taggit_serializer.serializers import TagListSerializerField, TaggitSerializer
+from .serializers import TagListSerializerField, TaggitSerializer
 
 
 class TaggableSerializer(TaggitSerializer):
