@@ -1,4 +1,4 @@
-from datetime import timedelta
+from datetime import timedelta, datetime
 
 from django.conf import settings
 from django.utils.timezone import is_aware, make_aware, is_naive, make_naive
@@ -13,7 +13,20 @@ def fix_timezone(value, timezone=None, is_dst=None):
     return value
 
 
+def as_date(value):
+    if isinstance(value, datetime):
+        return value.date()
+
+    return value
+
+
 def get_weekdays_between(start, end):
+    if isinstance(start, datetime):
+        start = start.date()
+
+    if isinstance(end, datetime):
+        end = end.date()
+
     dt = start
 
     dates = []
@@ -24,8 +37,8 @@ def get_weekdays_between(start, end):
         if weekday > 5:
             dt += timedelta(days=8 - weekday)
 
-        dates.append(dt)
-
-        dt += timedelta(days=1)
+        if dt <= end:
+            dates.append(dt)
+            dt += timedelta(days=1)
 
     return dates
