@@ -2,6 +2,9 @@ import decimal
 
 
 def drop_zeros(number):
+    if number is None:
+        return number
+
     if not isinstance(number, decimal.Decimal):
         number = decimal.Decimal(number)
 
